(add-delay-fn {:keys [current-scene] :as state} d)Add a delay-fn into the current scene.
Add a delay-fn into the current scene.
(add-delay-fns {:keys [current-scene] :as state} ds)Add a collection of delay-fns into the current scene.
Add a collection of delay-fns into the current scene.
(apply-all state finished)apply a collection of finished delay-fns to the state.
apply a collection of finished delay-fns to the state.
(sequential-delay-fns delay-datas
&
{:keys [initial-delay tag]
:or {initial-delay 0 tag :none}})Creates a sequence of delay-fns from a given list of [time-ms on-complete-fn] tuples where each time-ms is relative to the
ending of the previous one.
Creates a sequence of delay-fns from a given list of `[time-ms on-complete-fn]` tuples where each `time-ms` is relative to the ending of the previous one.
(update-delay-fn dt d)Decrement the time remaining since the last frame.
Decrement the time remaining since the last frame.
(update-state {:keys [current-scene dt] :as state})Update all the delay-fns in the current scene and apply the ones that have finished.
Update all the delay-fns in the current scene and apply the ones that have finished.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |