(compile-user-shaders configs)(default-shader-programs)These shader programs need an orthographic projection matrix and a model matrix supplied as uniforms.
These shader programs need an orthographic projection matrix and a model matrix supplied as uniforms.
(program vertex-shader-path
fragment-shader-path
&
{:keys [geometry-shader-path]})Create a shader program from a vertex shader filepath and fragment shader filepath.
Create a shader program from a vertex shader filepath and fragment shader filepath.
(use-line-shader {:keys [window] :as state} color line-width)(use-program shader-program)(use-solid-poly-shader state color)(use-texture-shader state)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |