clunk.shader


default-shader-programsclj

(default-shader-programs)

These shader programs need an orthographic projection matrix and a model matrix supplied as uniforms.

These shader programs need an orthographic projection matrix and a
model matrix supplied as uniforms.
sourceraw docstring

programclj

(program vertex-shader-path
         fragment-shader-path
         &
         {:keys [geometry-shader-path]})

Create a shader program from a vertex shader filepath and fragment shader filepath.

Create a shader program from a vertex shader filepath and fragment shader filepath.
sourceraw docstring

use-line-shaderclj

(use-line-shader {:keys [window] :as state} color line-width)
source

use-programclj

(use-program shader-program)
source

use-solid-poly-shaderclj

(use-solid-poly-shader state color)
source

use-texture-shaderclj

(use-texture-shader state)
source

cljdoc builds & hosts documentation for Clojure/Script libraries