clunk.tween

Tween library for interpolating game object properties between absolute or relative values.

Comprehensive easing functions for different interpolation curves.

Tween library for interpolating game object properties between
absolute or relative values.

Comprehensive easing functions for different interpolation curves.
raw docstring

add-tweenclj

(add-tween {:keys [tweens] :as sprite} tween)
source

apply-tweenclj

(apply-tween sprite
             {:keys [delay field update-fn yoyo? yoyoing? yoyo-update-fn
                     total-change normalized-deltas progress resetting?]})
source

complete-repetitionclj

(complete-repetition {:keys [repeat-times on-repeat-delay resetting?]
                      :as tween})
source

ease-in-backclj

(ease-in-back x)
source

ease-in-bounceclj

(ease-in-bounce x)
source

ease-in-circclj

(ease-in-circ x)
source

ease-in-cubicclj

(ease-in-cubic x)
source

ease-in-elasticclj

(ease-in-elastic x)
source

ease-in-expoclj

(ease-in-expo x)
source

ease-in-out-backclj

(ease-in-out-back x)
source

ease-in-out-bounceclj

(ease-in-out-bounce x)
source

ease-in-out-circclj

(ease-in-out-circ x)
source

ease-in-out-cubicclj

(ease-in-out-cubic x)
source

ease-in-out-elasticclj

(ease-in-out-elastic x)
source

ease-in-out-expoclj

(ease-in-out-expo x)
source

ease-in-out-quadclj

(ease-in-out-quad x)
source

ease-in-out-quartclj

(ease-in-out-quart x)
source

ease-in-out-quintclj

(ease-in-out-quint x)
source

ease-in-out-sineclj

(ease-in-out-sine x)
source

ease-in-quadclj

(ease-in-quad x)
source

ease-in-quartclj

(ease-in-quart x)
source

ease-in-quintclj

(ease-in-quint x)
source

ease-in-sineclj

(ease-in-sine x)
source

ease-linearclj

source

ease-out-backclj

(ease-out-back x)
source

ease-out-bounceclj

(ease-out-bounce x)
source

ease-out-circclj

(ease-out-circ x)
source

ease-out-cubicclj

(ease-out-cubic x)
source

ease-out-elasticclj

(ease-out-elastic x)
source

ease-out-expoclj

(ease-out-expo x)
source

ease-out-quadclj

(ease-out-quad x)
source

ease-out-quartclj

(ease-out-quart x)
source

ease-out-quintclj

(ease-out-quint x)
source

ease-out-sineclj

(ease-out-sine x)
source

ease-sigmoidclj

(ease-sigmoid x)
source

handle-on-completesclj

(handle-on-completes {:keys [tweens] :as sprite})
source

handle-on-repeatsclj

(handle-on-repeats {:keys [tweens] :as sprite})
source

handle-on-yoyosclj

(handle-on-yoyos {:keys [tweens] :as sprite})
source

normalized-deltasclj

(normalized-deltas easing-fn step-count)
source

remove-completed-tweensclj

(remove-completed-tweens sprites)
source

tweenclj

(tween field
       to-value
       &
       {:keys [from-value easing-fn update-fn step-count yoyo? yoyo-update-fn
               on-yoyo-fn repeat-times on-repeat-fn on-repeat-delay
               on-complete-fn initial-delay]
        :or {yoyo? false
             step-count 100
             from-value 0
             on-repeat-delay 0
             on-complete-fn identity
             initial-delay 0
             yoyo-update-fn -
             easing-fn ease-linear
             update-fn +
             on-repeat-fn identity
             repeat-times 1
             on-yoyo-fn identity}})

Create a new tween for modifying a field on a sprite over time.

Create a new tween for modifying a field on a sprite over time.
sourceraw docstring

tween-to-colorclj

(tween-to-color s c)
(tween-to-color {sprite-color :color :as sprite} target-color opts)

Add appropriate tweens to a sprite with 3 or 4 length :color vector to morph it to a desired colour.

The optional opts argument can contain any of the standard tween options.

Add appropriate tweens to a sprite with 3 or 4 length `:color` vector
to morph it to a desired colour.

The optional `opts` argument can contain any of the standard tween
options.
sourceraw docstring

tween-x-fnclj

(tween-x-fn [x y] d)
source

tween-x-yoyo-fnclj

(tween-x-yoyo-fn [x y] d)
source

tween-y-fnclj

(tween-y-fn [x y] d)
source

tween-y-yoyo-fnclj

(tween-y-yoyo-fn [x y] d)
source

update-spriteclj

(update-sprite {:keys [tweens] :as sprite})
source

update-stateclj

(update-state {:keys [current-scene] :as state})
source

update-tweenclj

(update-tween {:keys [delay progress step-count yoyo? yoyoing? repeat-times]
               :as tween})
source

cljdoc builds & hosts documentation for Clojure/Script libraries